<?php
/**
 * Helper functions for theme presentation.
 *
 * @version		$Rev: 835 $
 * @author		Jordi Canals
 * @copyright   Copyright (C) 2009, 2010 Jordi Canals
 * @license		GNU General Public License version 2
 * @link		http://alkivia.org
 * @package		Alkivia
 * @subpackage	Chameleon
 *

	Copyright 2009, 2010 Jordi Canals <devel@jcanals.cat>

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	version 2 as published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

require_once( AK_LIB . '/filesystem.php' );

if ( ! function_exists('ak_chameleon_menubar') ) :
	/**
	 * Creates the header menu bar based on settings.
	 *
	 * @uses apply_filters() Calls the 'ak_chameleon_pages_menu' hook on the menu page list.
	 * @uses apply_filters() Calls the 'register' hook on register/admin item. (Default WP hook).
	 * @uses apply_filters() Calls the 'loginout' hook on login/logout item. (Default WP hook).
	 *
	 * @return string HTML formated menu bar.
	 */
    function ak_chameleon_menubar()
    {
	    $settings = ak_theme_option();

    	$menu = '<ul id="ddmenu">';
	    $link = '';

    	if ( $settings['menu-home'] ) {
    	    $class = ( is_front_page() ) ? ' class="current_page_item"' : '';
	    	$menu .= '<li' . $class . '><a href="' . get_bloginfo('url') . '" title="' . get_bloginfo('name') . '"'
	    		  . '>' . __('Home', 'aktheme') . '</a></li>';
    	}

        $ctitle = ( empty($settings['menu-categories-title']) ) ? __('Categories', 'aktheme') : $settings['menu-categories-title'];
    	if ( $settings['menu-categories'] ) {
    	    $c_menu  = '<a href="#">' . $ctitle . '</a>' . PHP_EOL . '<ul>';
	        $c_menu .= wp_list_categories('title_li=&echo=0&depth=1&use_desc_for_title=0&exclude=' . $settings['menu-set-categories']);
    	    $c_menu .= '</ul></li>' .PHP_EOL;

    	    if ( false !== strpos($c_menu, 'current-cat') ) {
                $menu .= '<li class="current_page_item">' . $c_menu;
    	    } else {
    	        $menu .= '<li>' . $c_menu;
    	    }
    	}

	    if ( ! empty($settings['menu-set-categories']) ) {
    	    $menu_cats = explode(',', $settings['menu-set-categories']);
    	    $args = array('title_li' => '', 'echo' => 0, 'depth' => 1, 'use_desc_for_title' => 0);

    	    foreach ( $menu_cats as $category) {
	            $args['child_of'] = trim($category);
	            $c_menu  = '<a href="' . get_category_link($category)
                         .  '">' . get_the_category_by_ID($category) . '</a>' . PHP_EOL;

                $subcats = get_categories($args);
                if ( ! empty($subcats) ) {
                    $c_menu .= '<ul>' . PHP_EOL;
        	        $c_menu .= wp_list_categories('title_li=&echo=0&depth=1&child_of=' . trim($category) . '&use_desc_for_title=0');
        	        $c_menu .= '</ul>' . PHP_EOL;
                }

       	        if ( false !== strpos($c_menu, 'current-cat') || is_category($category) ) {
                    $menu .= '<li class="current_page_item">' . $c_menu . '</li>' . PHP_EOL;
        	    } else {
        	        $menu .= '<li>' . $c_menu . '</li>' . PHP_EOL;
            	}
	        }
    	}

    	if ( 'page' == get_option('show_on_front') ) {
	        $front_id = get_option('page_on_front');
    	} else {
	        $front_id = get_option('page_for_posts');
    	}

    	$exclude = ak_theme_option('menu-exclude-pages');
    	if ( is_string($exclude) ) {
    	    $exclude .= ',' . $front_id;
    	} else {
    	    $exclude = $front_id;
    	}

    	$pages = apply_filters('ak_chameleon_pages_menu', wp_list_pages('title_li=&depth=2&echo=0&exclude=' . $exclude));
    	if ( is_category() ) {
    	    $menu .= str_replace('current_page_parent', '', $pages);
    	} else {
    	    $menu .= $pages;
    	}

    	if ( $settings['menu-admin'] ) {
	    	// WP-REGISTER
    		if ( is_user_logged_in() ) {
	    		$link = '<li><a href="' . admin_url() . '">' . __('Site Admin', 'aktheme') . '</a></li>';
    		} else {
	    		if ( get_option('users_can_register') ) {
		    		$link = '<li><a href="' . site_url('wp-login.php?action=register', 'login') . '">' . __('Register', 'aktheme') . '</a></li>';
			    }
    		}
	    	$menu .= apply_filters('register', $link);
    	}

	    if ( $settings['menu-login'] ) {
		    // WP_LOGINOUT
    		if ( is_user_logged_in() ) {
	    		$link = '<a href="' . wp_logout_url() . '">' . __('Log out', 'aktheme') . '</a>';
    		} else {
	    		$link = '<a href="' . wp_login_url() . '">' . __('Log in', 'aktheme') . '</a>';
		    }
    		$menu .= '<li>'. apply_filters('loginout', $link) .'</li>';
	    }
    	$menu .= '</ul>' . PHP_EOL;

    	return $menu;
    }
endif;

if ( ! function_exists('ak_chameleon_footer') ) :
	/**
	 * Returns the footer text defined in Chameleon Settings.
	 *
	 * @return string Footer text.
	 */
    function ak_chameleon_footer()
    {
    	return str_replace("\n", '<br />', ak_theme_option('footer-text')) . '<br />';
    }
endif;

if ( ! function_exists('ak_chameleon_navigator') ) :
	/**
	 * Draws the posts navigator bar
	 *
	 * @param string $class CSS class style
	 * @return void
	 */
    function ak_chameleon_navigator( $class = '' )
    {
    	global $wp_query;

    	$naviclass = ( empty($class) ) ? 'navigator' : "navigator {$class}";

	    if ( is_single () ) { ?>
			<div class="<?php echo $naviclass; ?>">
				<div class="navleft"><?php previous_post_link('&laquo; %link') ?></div>
				<div class="navright"><?php next_post_link('%link &raquo;') ?></div>
			</div>
	    <?php } elseif ( function_exists('wp_pagenavi') ) {
		    $naviclass = ( 'bottom-navigator' == $class ) ? 'pagenavi-container pagenavi-bottom' : 'pagenavi-container';
    		echo '<div class="'. $naviclass .'">';
	    	wp_pagenavi();
		    echo '</div>';
    	} else {
	    	if ( $wp_query->found_posts > get_option('posts_per_page') || is_paged()) {
    		?>
				<div class="<?php echo $naviclass; ?>">
					<div class="navleft"><?php next_posts_link('&laquo; ' . __('Older Posts', 'aktheme')) ?></div>
					<div class="navright"><?php previous_posts_link(__('Newer Posts', 'aktheme') . ' &raquo;'); ?></div>
				</div>
			<?php } ?>
	    <?php }
    }
endif;

if ( ! function_exists('ak_chameleon_palettes') ) :
	/**
	 * Gets all theme palettes: Custom, child and parent.
	 *
	 * @return array Palettes list.
	 */
    function ak_chameleon_palettes()
    {
        $args = 'extensions=css&tree=0&with_ext=0';
        $dir  = ak_theme_option('custom-palettes-dir');

        if ( false !== $dir && is_dir($dir) ) {
            $custom = ak_dir_content($dir, $args);
        } else {
            $custom = array();
        }

        if ( STYLESHEETPATH !== TEMPLATEPATH && is_dir(STYLESHEETPATH . '/styles') ) {
            $child = array_diff(ak_dir_content(STYLESHEETPATH . '/styles', $args), $custom);
        } else {
            $child = array();
        }

        $parent = array_diff(ak_dir_content(TEMPLATEPATH . '/styles', $args), $child, $custom);

        $palettes = array_merge($parent, $child, $custom);
        sort($palettes);
        return $palettes;
    }
endif;
