<?php
/**
 * Style selector widget.
 *
 * @version		$Rev: 477 $
 * @author		Jordi Canals
 * @copyright   Copyright (C) 2009, 2010 Jordi Canals
 * @license		GNU General Public License version 2
 * @link		http://alkivia.org
 * @package		Alkivia
 * @subpackage	Chameleon
 *

	Copyright 2009, 2010 Jordi Canals <devel@jcanals.cat>

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	version 2 as published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Widget class for users lists.
 * Always shows the same output format and control.
 * Must define the methods startUp() and widget()
 *
 * @package AOC
 * @subpackage Library
 * @since 0.8
 */
final class chameleonPalettes extends WP_Widget
{
    /**
     * Plugin ID and translation textDomain.
     * @var string
     */
    private $pid;

    /**
     * Class constructor.
     * @see WP_Widget::__construct()
     */
    public function __construct()
    {
        global $SidePosts;
        $this->pid = ak_theme()->ID;     // Translation textdomain.

		$options = array('classname' => 'widget_palettes', 'description' => __('Select Chameleon theme palettes.', $this->pid) );
        parent::__construct($this->pid, __('Chameleon Palettes', $this->pid), $options );
    }

	/**
	 * Widget Output
	 * @see WP_Widget::widget()
	 */
    public function widget( $args, $instance )
    {
        $palettes = ak_chameleon_palettes();
		extract( $args, EXTR_SKIP );

		echo $before_widget;
	    if ( !empty($instance['title']) ) {
		    echo $before_title. $instance['title'] . $after_title;
    	}
	    echo '<div class="textwidget" style="text-align:center;">' . PHP_EOL;

        if ( isset($_GET['theme-style']) ) {
    		$current = strtolower($_GET['theme-style']);
	    } elseif ( isset($_COOKIE['chameleon-style']) ) {
		    $current = strtolower($_COOKIE['chameleon-style']);
    	} else {
            $current = ak_theme()->getOption('palette');
    	}
    ?>
	    <form method="get">
			<select name="theme-style" style="margin: 5px 0">
				<?php foreach ($palettes as $style) {
				    echo "<option value='{$style}'";
				    if ( $current == $style) {
				        echo " selected='selected'";
				    }
				    echo "> " . ucfirst($style) . "&nbsp;</option>";
				} ?>
			</select>
			<input type="submit" value="Change" style="margin: 5px 0" />
	    </form>
	<?php
	    echo '</div>' . PHP_EOL;
	    echo $after_widget;
    }

    /**
     * Widget Control form.
     * @see WP_Widget::form()
     */
    public function form( $instance )
    {
        $defaults = array ( 'title'      => '' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		$title = attribute_escape($instance['title']);
	?>
		<p><?php _e('Title:', $this->pid); ?> <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" /></p>
	<?php
    }

    /**
     * Widget data validation.
     * @see WP_Widget::update()
     */
    public function update ( $newInstance, $oldInstance )
    {
    	$instance['title'] = strip_tags(stripslashes($newInstance['title']));
		return $instance;
    }

}
